@@ -20,7 +20,6 @@
 #include <iomanip>
 #include <assert.h>
 #include <sigc++/functors/mem_fun.h>
-#include <string.h>
 #include <math.h>
 
 #include "ucompose.hpp"
@@ -130,7 +129,6 @@ GameMap::GameMap(XML_Helper* helper)
 
 }
 
-
 GameMap::~GameMap()
 {
     for (int i = 0; i < s_width; i++)
@@ -169,12 +167,6 @@ bool GameMap::save(XML_Helper* helper) const
     return retval;
 }
 
-void GameMap::setTile(int x, int y, Maptile *tile)
-{
-    delete d_map[y*s_width + x];
-    d_map[y*s_width + x] = tile;
-}
-
 Maptile* GameMap::getTile(int x, int y) const
 {
   if (x < 0 && x >= s_width && y < 0 && y >= s_height)
@@ -186,11 +178,6 @@ Maptile* GameMap::getTile(int x, int y) const
   return d_map[y*s_width + x];
 }
 
-Stack* GameMap::addArmy(Vector<int> pos, Army *a)
-{
-  return addArmyAtPos(pos, a);
-}
-
 Stack* GameMap::addArmyAtPos(Vector<int> pos, Army *a)
 {
   Stack *s = NULL;
@@ -301,12 +288,12 @@ std::list<Stack*> GameMap::getFriendlyStacks(Vector<int> pos, Player *player)
     player = Playerlist::getActiveplayer();
   return getStacks(pos)->getFriendlyStacks(player);
 }
-	
+
 Stack* GameMap::getEnemyStack(Vector<int> pos)
 {
   return getStacks(pos)->getEnemyStack(Playerlist::getActiveplayer());
 }
-	
+
 std::list<Stack*> GameMap::getEnemyStacks(std::list<Vector<int> > positions)
 {
   std::list<Stack*> enemy_stacks;
@@ -331,13 +318,12 @@ Stack* GameMap::getStack(Vector<int> pos)
 {
   return getStacks(pos)->getStack();
 }
-	
+
 StackTile* GameMap::getStacks(Vector<int> pos)
 {
   return getInstance()->getTile(pos)->getStacks();
 }
 
-  
 void GameMap::clearStackPositions()
 {
   Playerlist *plist = Playerlist::getInstance();
@@ -348,6 +334,7 @@ void GameMap::clearStackPositions()
 	getStacks((*s)->getPos())->clear();
     }
 }
+
 void GameMap::updateStackPositions()
 {
   Playerlist *plist = Playerlist::getInstance();
@@ -371,133 +358,7 @@ bool GameMap::canAddArmy(Vector<int> dest)
     return true;
   return false;
 }
-bool GameMap::canAddArmies(Vector<int> dest, guint32 stackSize)
-{
-  if (countArmyUnits(dest) + stackSize <= MAX_ARMIES_ON_A_SINGLE_TILE)
-    return true;
-  return false;
-}
 
-bool GameMap::canPutStack(guint32 size, Player *p, Vector<int> to)
-{
-  StackTile *stile = GameMap::getInstance()->getStacks(to);
-  if (!stile)
-    return true;
-  if (stile->canAdd(size, p) == true)
-    return true;
-  return false;
-
-}
-
-bool GameMap::moveStack(Stack *stack, Vector<int> to)
-{
-  bool moved = true;
-  if (stack->getPos() == to)
-    return true;
-  if (canPutStack(stack->size(), stack->getOwner(), to) == false)
-    return false;
-
-
-  getStacks(stack->getPos())->leaving(stack);
-  stack->setPos(to);
-  //Stack *new_stack = new Stack(*stack);
-  //new_stack->setPos(to);
-  //getStacks(stack->getPos())->leaving(stack);
-  //delete stack;
-  //if we dropped it on a city, then change the ownership.
-  getStacks(stack->getPos())->arriving(stack);
-
-  return moved;
-}
-	
-bool GameMap::putStack(Stack *s)
-{
-  Playerlist::getActiveplayer()->addStack(s);
-  getStacks(s->getPos())->add(s);
-  return true;
-}
-
-void GameMap::removeStack(Stack *s)
-{
-  getStacks(s->getPos())->leaving(s);
-  s->getOwner()->deleteStack(s);
-}
-	
-std::list<Stack*> GameMap::getNearbyFriendlyStacks(Vector<int> pos, int dist)
-{
-  return getNearbyStacks(pos, dist, true);
-}
-
-std::list<Stack*> GameMap::getNearbyEnemyStacks(Vector<int> pos, int dist)
-{
-  return getNearbyStacks(pos, dist, false);
-}
-
-std::list<Stack*> GameMap::getNearbyStacks(Vector<int> pos, int dist, bool friendly)
-{
-  std::list<Vector<int> > points = getNearbyPoints(pos, dist);
-  std::list<Stack*> stks;
-  std::list<Stack *> stacks;
-  for (std::list<Vector<int> >::iterator it = points.begin(); 
-       it != points.end(); it++)
-    {
-      if (friendly)
-        stks = GameMap::getFriendlyStacks(*it);
-      else
-        stks = GameMap::getEnemyStacks(*it);
-      stacks.merge(stks);
-    }
-
-  return stacks;
-}
-
-std::list<Vector<int> > GameMap::getNearbyPoints(Vector<int> pos, int dist)
-{
-  std::list<Vector<int> > points;
-  guint32 i, j;
-  guint32 d;
-  guint32 max = dist;
-  int x, y;
-
-  points.push_back(pos);
-
-  if (dist == -1)
-    {
-      if (getWidth() > getHeight())
-        max = getWidth();
-      else
-        max = getHeight();
-    }
-  //d is the distance from Pos where our box starts
-  //instead of a regular loop around a box of dist large, we're going to add
-  //the nearer stacks first.
-  for (d = 1; d <= max; d++)
-    {
-      for (i = 0; i < (d * 2) + 1; i++)
-        {
-          for (j = 0; j < (d * 2) + 1; j++)
-            {
-              if ((i == 0 || i == (d * 2)) ||
-                  (j == 0 || j == (d * 2)))
-                {
-                  x = pos.x + (i - d);
-                  y = pos.y + (j - d);
-		  if (offmap(x, y))
-		    continue;
-                  points.push_back(Vector<int>(x,y));
-                }
-            }
-        }
-    }
-
-  return points;
-}
-
-Vector<int> GameMap::getCenterOfMap()
-{
-  return Vector<int>(GameMap::s_width/2, GameMap::s_height/2);
-}
-        
 Raft* GameMap::getRaft(Vector<int> pos)
 {
   Raftlist *rl = Raftlist::getInstance();
