@@ -74,26 +74,16 @@ class GameMap: public sigc::trackable
 	static Rectangle get_boundary()
 	    { return Rectangle(0, 0, s_width, s_height); }
 
-	//! Sets the tile object at position (x, y)
-	void setTile(int x, int y, Maptile *tile);
-        
-        //! Alternative setting
-        void setTile(Vector<int> p, Maptile *t) {return setTile(p.x, p.y, t);}
-
         static Raft* getRaft(Vector<int> pos);
 	static Stack* getStack(Vector<int> pos);
 	static StackTile* getStacks(Vector<int> pos);
 	static bool canAddArmy(Vector<int> pos);
-	static bool canAddArmies(Vector<int> dest, guint32 stackSize);
 	static Stack* getFriendlyStack(Vector<int> pos);
 	static std::list<Stack*> getFriendlyStacks(Vector<int> pos, Player *player = NULL);
 	static Stack* getEnemyStack(Vector<int> pos);
 	static std::list<Stack*> getEnemyStacks(std::list<Vector<int> > posns);
 	static std::list<Stack*> getEnemyStacks(Vector<int> pos, Player *player = NULL);
-	static std::list<Stack*> getNearbyFriendlyStacks(Vector<int> pos, int dist);
-	static std::list<Stack*> getNearbyEnemyStacks(Vector<int> pos, int dist);
 
-        static std::list<Vector<int> > getNearbyPoints(Vector<int> pos, int dist);
 	static guint32 countArmyUnits(Vector<int> pos);
 
         static std::list<Vector<int> > getPointsInLine(Vector<int> s, Vector<int> d);
@@ -109,9 +99,7 @@ class GameMap: public sigc::trackable
         Maptile* getTile(Vector<int> p) const {return getTile(p.x, p.y);}
 
 	//! Add an army to this location on the map
-        Stack* addArmy(Vector<int> pos, Army *a);
         Stack* addArmyAtPos(Vector<int> pos, Army *a);
-        void addArmies(const ArmyProto *a, guint32 num_allies, Vector<int> pos);
 
 	//! go find the player's stack, the slow way.
 	Vector<int> findStack(guint32 id);
@@ -129,13 +117,6 @@ class GameMap: public sigc::trackable
 	void updateStackPositions();
         void clearStackPositions();
 
-	bool canPutStack(guint32 size, Player *p, Vector<int> to);
-	bool moveStack(Stack *stack, Vector<int> to);
-
-	bool putStack(Stack *s);
-	void removeStack(Stack *s);
-
-        static Vector<int> getCenterOfMap();
         std::list<Vector<int> > getBricks() const;
 
     protected:
@@ -150,8 +131,6 @@ class GameMap: public sigc::trackable
         //! Callback for item loading used during loading.
         bool isBlockedAvenue(int x, int y, int destx, int desty);
 
-	static std::list<Stack*> getNearbyStacks(Vector<int> pos, int dist, bool friendly);
-
 	static bool offmap(int x, int y);
 
         // Data
