@@ -22,7 +22,6 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <sigc++/functors/mem_fun.h>
-#include <string.h>
 
 #include "ucompose.hpp"
 #include "GameScenario.h"
@@ -35,10 +34,8 @@
 #include "player.h"
 #include "Configuration.h"
 #include "real_player.h"
-#include "ai_dummy.h"
 #include "counter.h"
 #include "army.h"
-#include "player.h"
 #include "history.h"
 #include "xmlhelper.h"
 #include "tarhelper.h"
@@ -418,21 +415,6 @@ GameScenario::setNewRandomId ()
   d_id = generate_guid ();
 }
 
-bool
-GameScenario::validate (std::list < Glib::ustring > &errors,
-			std::list < Glib::ustring > &warnings)
-{
-  Glib::ustring s;
-  Playerlist *pl = Playerlist::getInstance ();
-  guint32 num = pl->countPlayersAlive ();
-  if (num < 2)
-    errors.push_back ("There must be at least 2 players in the scenario.");
-
-  if (errors.size () == 0)
-    return true;
-  return false;
-}
-
 void
 GameScenario::initialize (GameParameters g)
 {
