@@ -18,7 +18,6 @@
 #ifndef GAME_SCENARIO_H
 #define GAME_SCENARIO_H
 
-#include <string>
 #include <list>
 #include <sigc++/trackable.h>
 #include "game-parameters.h"
@@ -85,18 +84,6 @@ class GameScenario: public GameScenarioOptions
         //! via a signal.
         void nextRound();
 
-        //! Sets the name of the scenario.
-        void setName(Glib::ustring name) {d_name = name;}
-
-        //! Sets the description of the scenario.
-        void setComment(Glib::ustring comment) {d_comment = comment;}
-        
-        //! Sets the copyright of the scenario.
-        void setCopyright(Glib::ustring copy) {d_copyright = copy;}
-        
-        //! Sets the license of the scenario.
-        void setLicense(Glib::ustring license) {d_license = license;}
-        
         /** Saves the game. See XML_Helper for further explanations.
           * 
           * @param filename     the full name of the save game file
@@ -110,7 +97,6 @@ class GameScenario: public GameScenarioOptions
 	guint32 getPlayMode() const {return d_playmode;};
 	void setPlayMode(GameScenario::PlayMode mode) {d_playmode = mode;};
 
-	bool validate(std::list<Glib::ustring> &errors, std::list<Glib::ustring> &warnings);
 
         void clean_tmp_dir() const;
 
