@@ -18,11 +18,9 @@
 #ifndef GRAPHICS_CACHE_H
 #define GRAPHICS_CACHE_H
 
-#include <string>
 #include <list>
 #include <map>
 #include <vector>
-#include <string.h>
 #include <cairomm/context.h>
 
 #include "player.h"
