@@ -18,7 +18,6 @@
 #include <iostream>
 #include "defs.h"
 #include "PixMask.h"
-#include <string.h>
 #include <cairomm/cairomm.h>
 #include <gdkmm.h>
 #include "ucompose.hpp"
@@ -163,12 +162,6 @@ PixMask* PixMask::copy()
   return new PixMask(*this);
 }
 
-void PixMask::blit_centered(Cairo::RefPtr<Cairo::Surface> dest, Vector<int> pos)
-{
-  blit (dest, pos.x - (width/2), pos.y - (height/2));
-  return;
-}
-
 void PixMask::blit(Cairo::RefPtr<Cairo::Surface> dest, Vector<int> pos)
 {
   blit (dest, pos.x, pos.y);
