@@ -89,16 +89,12 @@ Action* Action::handle_load(XML_Helper* helper)
           return (new Action_Move(helper));
       case STACK_FIGHT:
           return (new Action_Fight(helper));
-      case RESIGN:
-          return (new Action_Resign(helper));
       case END_TURN:
           return (new Action_EndTurn(helper));
       case INIT_TURN:
           return (new Action_InitTurn(helper));
       case KILL_PLAYER:
           return (new Action_Kill(helper));
-      case PLAYER_RENAME:
-          return (new Action_RenamePlayer(helper));
       case STACK_SELECT:
           return (new Action_SelectStack(helper));
       case STACK_DESELECT:
@@ -121,16 +117,10 @@ Action* Action::copy(const Action* a)
             return (new Action_Move(*dynamic_cast<const Action_Move*>(a)));
         case STACK_FIGHT:
             return (new Action_Fight(*dynamic_cast<const Action_Fight*>(a)));
-        case RESIGN:
-            return (new Action_Resign(*dynamic_cast<const Action_Resign*>(a)));
         case END_TURN:
             return 
               (new Action_EndTurn
                 (*dynamic_cast<const Action_EndTurn*>(a)));
-        case PLAYER_RENAME:
-            return 
-              (new Action_RenamePlayer
-                (*dynamic_cast<const Action_RenamePlayer*>(a)));
         case INIT_TURN:
             return 
               (new Action_InitTurn
@@ -401,49 +391,6 @@ bool Action_Fight::is_army_id_in_stacks(guint32 id, std::list<guint32> stack_ids
     return false;
 }
 
-
-//-----------------------------------------------------------------------------
-//Action_Resign
-
-Action_Resign::Action_Resign()
-:Action(Action::RESIGN)
-{
-}
-
-Action_Resign::Action_Resign(const Action_Resign &action)
-: Action(action)
-{
-}
-
-Action_Resign::Action_Resign(XML_Helper* helper)
-:Action(helper)
-{
-}
-
-Action_Resign::~Action_Resign()
-{
-}
-
-Glib::ustring Action_Resign::dump() const
-{
-  std::stringstream s;
-  s << "this player resigns\n";
-
-  return s.str();
-}
-
-bool Action_Resign::doSave(XML_Helper* helper) const
-{
-  bool retval = true;
-
-  return retval;
-}
-
-bool Action_Resign::fillData()
-{
-  return true;
-}
-
 //-----------------------------------------------------------------------------
 //Action_EndTurn
 
@@ -478,53 +425,6 @@ bool Action_EndTurn::doSave(XML_Helper* helper) const
   return retval;
 }
 
-//-----------------------------------------------------------------------------
-//Action_RenamePlayer
-
-Action_RenamePlayer::Action_RenamePlayer()
-  :Action(Action::PLAYER_RENAME), d_name("")
-{
-}
-
-Action_RenamePlayer::Action_RenamePlayer(const Action_RenamePlayer &action)
-:Action(action), d_name(action.d_name)
-{
-}
-
-Action_RenamePlayer::Action_RenamePlayer(XML_Helper* helper)
-  :Action(helper)
-{
-    helper->getData(d_name, "name");
-}
-
-Action_RenamePlayer::~Action_RenamePlayer()
-{
-}
-
-Glib::ustring Action_RenamePlayer::dump() const
-{
-    std::stringstream s;
-
-    s << "Player changes name to " << d_name <<".\n";
-
-    return s.str();
-}
-
-bool Action_RenamePlayer::doSave(XML_Helper* helper) const
-{
-    bool retval = true;
-
-    retval &= helper->saveData("name", d_name);
-
-    return retval;
-}
-
-bool Action_RenamePlayer::fillData(Glib::ustring name)
-{
-  d_name = name;
-  return true;
-}
-
 //-----------------------------------------------------------------------------
 //Action_InitTurn
 
@@ -830,12 +730,8 @@ Glib::ustring Action::actionTypeToString(Action::Type type)
       return "Action::STACK_MOVE";
     case Action::STACK_FIGHT:
       return "Action::STACK_FIGHT";
-    case Action::RESIGN:
-      return "Action::RESIGN";
     case Action::END_TURN:
       return "Action::END_TURN";
-    case Action::PLAYER_RENAME:
-      return "Action::PLAYER_RENAME";
     case Action::INIT_TURN:
       return "Action::INIT_TURN";
     case Action::KILL_PLAYER:
@@ -861,12 +757,8 @@ Action::Type Action::actionTypeFromString(Glib::ustring str)
     return Action::STACK_MOVE;
   else if (str == "Action::STACK_FIGHT")
     return Action::STACK_FIGHT;
-  else if (str == "Action::RESIGN")
-    return Action::RESIGN;
   else if (str == "Action::END_TURN")
     return Action::END_TURN;
-  else if (str == "Action::PLAYER_RENAME")
-    return Action::PLAYER_RENAME;
   else if (str == "Action::INIT_TURN")
     return Action::INIT_TURN;
   else if (str == "Action::STACK_SELECT")
