@@ -19,7 +19,6 @@
 #define ACTION_H
 
 #include <gtkmm.h>
-#include <string>
 #include "vector.h"
 #include <sigc++/trackable.h>
 
@@ -60,10 +59,7 @@ class Action
                 STACK_MOVE = 1,
 		/** A stack is fighting a city or another stack. */
                 STACK_FIGHT = 3,
-		/** A player has surrendered. */
-		RESIGN = 23,
                 END_TURN = 30,
-                PLAYER_RENAME = 33,
 		INIT_TURN = 35,
                 KILL_PLAYER = 42,
                 STACK_SELECT = 47,
@@ -229,35 +225,6 @@ class Action_EndTurn: public Action
 
 //-----------------------------------------------------------------------------
 
-class Action_RenamePlayer: public Action
-{
-    public:
-	//! Make a new rename player action
-        Action_RenamePlayer();
-	//! Copy constructor
-	Action_RenamePlayer(const Action_RenamePlayer &action);
-	//! Load a new rename player action from an opened saved-game file.
-        Action_RenamePlayer(XML_Helper* helper);
-	//! Destroy a rename player action.
-        ~Action_RenamePlayer();
-
-	//! Return some debug information about this action.
-        Glib::ustring dump() const;
-
-	//! Save this city occupied action to an opened saved-game file.
-        virtual bool doSave(XML_Helper* helper) const;
-
-	//! Populate the action.
-        bool fillData(Glib::ustring name);
-    
-	Glib::ustring getName() const {return d_name;};
-
-        private:
-	Glib::ustring d_name;
-};
-
-//-----------------------------------------------------------------------------
-
 class Action_InitTurn: public Action
 {
     public:
@@ -370,35 +337,6 @@ class Action_DeselectStack: public Action
 	//! The Action_DeselectStack class doesn't take any info to fill.
         bool fillData();
 };
-//-----------------------------------------------------------------------------
-
-//! A temporary record of a Player surrendering.
-/**
- * The purpose of the Action_Resign class is to record when a Player has
- * resigned from the game.  Because these actions are held in a Player's
- * Actionlist, we do not have to store the player's Id.
- */
-class Action_Resign: public Action
-{
-    public:
-	//! Make a new player resignation action.
-        Action_Resign();
-	//! Copy constructor
-	Action_Resign(const Action_Resign &action);
-	//! Load a new player resignation action from an opened saved-game file.
-        Action_Resign(XML_Helper* helper);
-	//! Destroy a player resignation action.
-        ~Action_Resign();
-
-	//! Return some debug information about this action.
-        Glib::ustring dump() const;
-
-	//! Save this player resignation action to an opened saved-game file.
-        virtual bool doSave(XML_Helper* helper) const;
-
-	//! This method doesn't need to be called for Action_Resign actions.
-        bool fillData();
-};
 
 //-----------------------------------------------------------------------------
 
