@@ -51,11 +51,6 @@ Army::Army(const ArmyProto& a, guint32 id, Player *p)
 {
 }
 
-Army* Army::createNonUniqueArmy(const ArmyProto& a, Player *player)
-{
-  return new Army(a, (guint32) 0, player);
-}
-
 Army::Army()
   :ArmyBase(), UniquelyIdentified(), Ownable((Player *)0),
     d_type_id(0), d_armyset(0)
