@@ -19,7 +19,6 @@
 #define ARMY_H
 
 #include <gtkmm.h>
-#include <string>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
 
@@ -68,14 +67,8 @@ class Army :public ArmyBase, public UniquelyIdentified, public Ownable, public s
 	//! Destructor.
         virtual ~Army();
 
-	static Army* createNonUniqueArmy(const ArmyProto& a, Player *p=NULL);
-
-
         // Set Methods
         
-        //! Set the Id of Armyset and type that this Army belongs to.
-        void setArmyset(guint32 armyset, guint32 type);
-	
 	//! Change the armyset that the army type for this army belongs to.
 	void setArmyset(guint32 armyset_id) {d_armyset = armyset_id;};
 
