@@ -19,7 +19,6 @@
 #define ARMY_PROTO_BASE_H
 
 #include <gtkmm.h>
-#include <string>
 
 #include "defs.h"
 
@@ -47,15 +46,9 @@ class ArmyProtoBase : public ArmyBase
         
         void setTypeId(guint32 type_id) {d_type_id = type_id;};
 
-        //! Sets the descriptive text for this Army.
-        void setDescription(Glib::ustring text) {d_description = text;};
-        
 	//! Sets the armyset id for this army.
 	void setArmyset(guint32 id) {d_armyset = id;};
 
-        //! Set the name of the Army.
-        void setName(Glib::ustring name){d_name = name;}
-
         // Get Methods
         
 	//! Get the Id of the Armyset to which the Army's type belongs.
