@@ -20,7 +20,6 @@
 #include <gtkmm.h>
 #include "rectangle.h"
 #include <sigc++/functors/mem_fun.h>
-#include <string>
 
 #include "shield.h"
 #include "armyset.h"
@@ -321,24 +320,6 @@ std::list<Glib::ustring> Armyset::scanSystemCollection()
   return retlist;
 }
 
-void Armyset::reload(bool &broken)
-{
-  broken = false;
-  bool unsupported = false;
-  ArmysetLoader d(getConfigurationFile(), broken, unsupported);
-  if (!broken && d.armyset && d.armyset->validate())
-    {
-      //steal the values from d.armyset and then don't delete it.
-      uninstantiateImages();
-      for (iterator it = begin(); it != end(); it++)
-        delete *it;
-      Glib::ustring basename = d_basename;
-      *this = *d.armyset;
-      instantiateImages(broken);
-      d_basename = basename;
-    }
-}
-
 Glib::ustring Armyset::getFileFromConfigurationFile(Glib::ustring file)
 {
   bool broken = false;
@@ -354,46 +335,6 @@ Glib::ustring Armyset::getFileFromConfigurationFile(Glib::ustring file)
   return "";
 }
 
-bool Armyset::replaceFileInConfigurationFile(Glib::ustring file, Glib::ustring new_file)
-{
-  bool broken = false;
-  Tar_Helper t(getConfigurationFile(), std::ios::in, broken);
-  if (broken == false)
-    {
-      broken = t.replaceFile(file, new_file);
-      t.Close();
-    }
-  return broken;
-}
-
-guint32 Armyset::calculate_preferred_tile_size() const
-{
-  guint32 tilesize = 0;
-  std::map<guint32, guint32> sizecounts;
-
-  if (d_raft)
-    sizecounts[d_raft->get_unscaled_width()]++;
-  for (const_iterator it = begin(); it != end(); it++)
-    {
-      ArmyProto *a = (*it);
-      sizecounts[a->getImage(Shield::BLUE)->get_unscaled_width()]++;
-    }
-
-  guint32 maxcount = 0;
-  for (std::map<guint32, guint32>::iterator it = sizecounts.begin(); 
-       it != sizecounts.end(); it++)
-    {
-      if ((*it).second > maxcount)
-        {
-          maxcount = (*it).second;
-          tilesize = (*it).first;
-        }
-    }
-  if (tilesize == 0)
-    tilesize = DEFAULT_ARMY_TILE_SIZE;
-  return tilesize;
-}
-
 void Armyset::clean_tmp_dir() const
 {
   return Tar_Helper::clean_tmp_dir(getConfigurationFile());
