@@ -19,7 +19,6 @@
 #define ARMYSET_H
 
 #include <gtkmm.h>
-#include <string>
 #include <map>
 #include <vector>
 #include <sigc++/trackable.h>
@@ -105,33 +104,15 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable, public Set
          */
         Glib::ustring getName() const {return d_name.c_str();}
 
-	//! Set the name of the armyset.
-	/**
-	 * @note This method is only used in the armyset editor.
-	 */
-        void setName(Glib::ustring name) {d_name = name;}
-
 	//! Get the copyright holders for this armyset.
 	Glib::ustring getCopyright() const {return d_copyright;};
 
-	//! Set the copyright holders on the armyset.
-	void setCopyright(Glib::ustring copy) {d_copyright = copy;};
-
 	//! Get the license of this armyset.
 	Glib::ustring getLicense() const {return d_license;};
 
         //! Returns the description of the armyset.
         Glib::ustring getInfo() const {return d_info.c_str();}
 
-	//! Set the license for this armyset.
-	void setLicense(Glib::ustring license) {d_license = license;};
-
-	//! Set the description of the armyset.
-	/**
-	 * @note This method is only used in the armyset editor.
-	 */
-        void setInfo(Glib::ustring info) {d_info = info;}
-
 	//! Get the base name of the armyset.
 	/**
 	 * This value does not contain a path (e.g. no slashes).  It is the
@@ -185,10 +166,6 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable, public Set
 	static std::list<Glib::ustring> scanSystemCollection();
 
         Glib::ustring getFileFromConfigurationFile(Glib::ustring file);
-        bool replaceFileInConfigurationFile(Glib::ustring file, Glib::ustring new_file);
-        //! Load the armyset again.
-        void reload(bool &broken);
-        guint32 calculate_preferred_tile_size() const;
 
     private:
 
