@@ -19,7 +19,6 @@
 #define ARMYSETLIST_H
 
 #include <gtkmm.h>
-#include <string>
 #include <map>
 #include <vector>
 #include <sigc++/trackable.h>
@@ -100,9 +99,7 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	
 
 	Armyset *import(Tar_Helper *t, Glib::ustring f, bool &broken);
-	bool addToPersonalCollection(Armyset *armyset, Glib::ustring &new_subdir, guint32 &new_id);
 
-        Glib::ustring findFreeBaseName(Glib::ustring basename, guint32 max, guint32 &num) const;
     private:
         //! Default Constructor.  Loads all armyset objects it can find.
 	/**
