@@ -19,7 +19,6 @@
 #define GAME_PARAMETERS_H
 
 #include <vector>
-#include <string>
 #include "player.h"
 
 class GameParameters
@@ -27,7 +26,7 @@ class GameParameters
 public:
     struct Player 
     {
-	enum Type { HUMAN, DUMMY, OFF};
+	enum Type { HUMAN, OFF};
 
 	Type type;
 	Glib::ustring name;
@@ -44,16 +43,12 @@ public:
     {
       if (type == 0) //Player::HUMAN
         return GameParameters::Player::HUMAN;
-      else if (type == 1) //Player:DUMMY:
-        return GameParameters::Player::DUMMY;
       return GameParameters::Player::OFF;
     }
   static guint32 player_param_to_player_type(guint32 param)
     {
       if (param == GameParameters::Player::HUMAN)
         return 0;
-      else if (param == GameParameters::Player::DUMMY)
-        return 1;
       else if (param == GameParameters::Player::OFF)
         return 0; //no equiv.
     }
@@ -61,8 +56,6 @@ public:
     {
       if (s == HUMAN_PLAYER_TYPE)
         return GameParameters::Player::HUMAN;
-      else if (s == DUMMY_PLAYER_TYPE)
-        return GameParameters::Player::DUMMY;
       else
         return GameParameters::Player::HUMAN;
     }
@@ -71,7 +64,6 @@ public:
       switch (type)
         {
         case GameParameters::Player::HUMAN: return HUMAN_PLAYER_TYPE;
-        case GameParameters::Player::DUMMY: return DUMMY_PLAYER_TYPE;
         case GameParameters::Player::OFF: return NO_PLAYER_TYPE;
         default: return NO_PLAYER_TYPE;
         }
