@@ -23,7 +23,6 @@
 #include <sigc++/connection.h>
 #include <memory>
 #include <list>
-#include <string>
 
 #include "rectangle.h"
 #include "army.h"
@@ -52,7 +51,6 @@ class Game
     Game(GameScenario* gameScenario, NextTurn *nextTurn);
     ~Game();
 
-    void redraw();
     void end_turn();
 
     void startGame(); // initiate game flow
@@ -89,9 +87,6 @@ class Game
     void stackUpdate(Stack* s);
     //! Called whenever players fight
     void on_fight_started(Fight &fight);
-    void nextRound();
-    void unselect_active_stack();
-    void select_active_stack();
     void stack_arrives_on_tile(Stack *stack, Vector<int> tile);
     void stack_leaves_tile(Stack *stack, Vector<int> tile);
     void on_stack_halted(Stack *stack);
@@ -102,7 +97,6 @@ class Game
     void on_player_died(Player *player);
     void init_turn_for_player(Player* p);
     void deselect_selected_stack();
-    void on_stack_selected(Stack* s);
 
     GameScenario* d_gameScenario;
     NextTurn* d_nextTurn;
