@@ -19,7 +19,6 @@
 #include <sigc++/functors/mem_fun.h>
 #include <sigc++/bind.h>
 #include <errno.h>
-#include <string.h>
 
 #include "driver.h"
 
@@ -37,7 +36,6 @@
 
 #include "NextTurnHotseat.h"
 #include "game.h"
-#include "timed-message-dialog.h"
 
 Driver::Driver (Glib::ustring load_filename)
 {
@@ -123,7 +121,6 @@ Driver::create_new_scenario (GameParameters & g, GameScenario::PlayMode m)
   if (broken)
     return NULL;
 
-  game_scenario->setName (g.name);
   game_scenario->setPlayMode (m);
 
   if (game_scenario->getRound () == 0)
@@ -145,25 +142,8 @@ Driver::on_new_game_requested (GameParameters g)
 
   if (game_scenario == NULL)
     {
-      TimedMessageDialog dialog (*game_window->get_window (),
-				 "Corrupted saved game file.", 0);
-      dialog.run ();
-      dialog.hide ();
-      game_window->hide ();
-      return;
-    }
-
-  std::list < Glib::ustring > e, w;
-  if (g.map_path != "" && game_scenario->validate (e, w) == false)
-    {
-      TimedMessageDialog dialog
-	(*game_window->get_window (),
-	 "Invalid map file.\n" "Please validate it manually.", 0);
-      std::list < Glib::ustring >::iterator it = e.begin ();
-      for (; it != e.end (); it++)
-	{
-	  printf ("error: %s\n", (*it).c_str ());
-	}
+      Gtk::MessageDialog dialog (*game_window->get_window (),
+				 "Corrupted saved game file.");
       dialog.run ();
       dialog.hide ();
       game_window->hide ();
@@ -246,8 +226,8 @@ Driver::load_game (Glib::ustring file_path)
 
   if (broken)
     {
-      TimedMessageDialog dialog (*game_window->get_window (),
-				 "Corrupted saved game file.", 0);
+      Gtk::MessageDialog dialog (*game_window->get_window (),
+				 "Corrupted saved game file.");
       dialog.run ();
       dialog.hide ();
       return NULL;
