@@ -20,7 +20,6 @@
 #include <iomanip>
 #include <queue>
 #include <assert.h>
-#include <string.h>
 
 #include <sigc++/functors/mem_fun.h>
 #include <sigc++/functors/ptr_fun.h>
@@ -28,6 +27,7 @@
 
 #include <gtkmm.h>
 #include <glib.h>
+#include <gtk/gtkshow.h>
 
 #include "game-window.h"
 
@@ -36,8 +36,6 @@
 
 #include "driver.h"
 
-#include "timed-message-dialog.h"
-
 #include "ucompose.hpp"
 #include "defs.h"
 #include "File.h"
@@ -954,16 +952,8 @@ void GameWindow::on_player_died(Player *player)
   Glib::ustring s;
   s += String::ucompose("The rule of %1 has permanently ended!",
 			player->getName());
-  if (Playerlist::getInstance()->countHumanPlayersAlive() == 0 &&
-      player->getType() == Player::HUMAN)
-    {
-      s += "\n";
-      s += "No further human resistance is possible\nbut the battle will continue!";
-      s += "\n";
-      s += "Press `CTRL-P' to stop the war\nand visit the sites of thy old battles.";
-    }
 
-  TimedMessageDialog dialog(*window, s, 30);
+  Gtk::MessageDialog dialog(*window, s);
 
   dialog.show_all();
   dialog.run();
@@ -1050,92 +1040,10 @@ void GameWindow::on_game_loaded(Player *player)
   delete dialog;
 }
 
-//taken from go-file.c of gnucash 2.0.4
-static char *
-check_program (char const *prog)
-{
-  if (NULL == prog)
-    return NULL;
-  if (g_path_is_absolute (prog)) {
-    if (!g_file_test (prog, G_FILE_TEST_IS_EXECUTABLE))
-      return NULL;
-  } else if (!g_find_program_in_path (prog))
-    return NULL;
-  return g_strdup (prog);
-}
-
-//taken from go-file.c of gnucash 2.0.4
-GError *
-go_url_show (gchar const *url)
-{
-  GError *err = NULL;
-  char *browser = NULL;
-  char *clean_url = NULL;
-
-  /* 1) Check BROWSER env var */
-  browser = check_program (getenv ("BROWSER"));
-
-  if (browser == NULL) {
-    static char const * const browsers[] = {
-      "sensible-browser",	/* debian */
-      "htmlview", /* fedora */
-      "firefox",
-      "epiphany",
-      "mozilla-firebird",
-      "mozilla",
-      "netscape",
-      "konqueror",
-      "xterm -e w3m",
-      "xterm -e lynx",
-      "xterm -e links"
-    };
-    unsigned i;
-    for (i = 0 ; i < G_N_ELEMENTS (browsers) ; i++)
-      if (NULL != (browser = check_program (browsers[i])))
-	break;
-  }
-
-  if (browser != NULL) {
-    gint    argc;
-    gchar **argv = NULL;
-    char   *cmd_line = g_strconcat (browser, " %1", NULL);
-
-    if (g_shell_parse_argv (cmd_line, &argc, &argv, &err)) {
-      /* check for '%1' in an argument and substitute the url
-       * 			 * otherwise append it */
-      gint i;
-      char *tmp;
-
-      for (i = 1 ; i < argc ; i++)
-	if (NULL != (tmp = strstr (argv[i], "%1"))) {
-	  *tmp = '\0';
-	  tmp = g_strconcat (argv[i],
-			     (clean_url != NULL) ? (char const *)clean_url : url,
-			     tmp+2, NULL);
-	  g_free (argv[i]);
-	  argv[i] = tmp;
-	  break;
-	}
-
-      /* there was actually a %1, drop the one we added */
-      if (i != argc-1) {
-	g_free (argv[argc-1]);
-	argv[argc-1] = NULL;
-      }
-      g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-		     NULL, NULL, NULL, &err);
-      g_strfreev (argv);
-    }
-    g_free (cmd_line);
-  }
-  g_free (browser);
-  g_free (clean_url);
-  return err;
-}
-
 void GameWindow::on_online_help_activated()
 {
-  go_url_show ("http://army.nongnu.org/army.html");
+  GError *errs = NULL;
+  gtk_show_uri(window->get_screen()->gobj(), "http://army.nongnu.org/army.html", 0, &errs);
   return;
 }
 
