@@ -27,7 +27,6 @@
 #include "stacklist.h"
 #include "armysetlist.h"
 #include "real_player.h"
-#include "ai_dummy.h"
 #include "GameMap.h"
 #include "counter.h"
 #include "army.h"
@@ -49,7 +48,7 @@ Player::Player(Glib::ustring name, guint32 armyset, Gdk::RGBA color,
 	       Type type, int player_no)
     :d_color(color), d_name(name), d_armyset(armyset),
     d_dead(false), d_immortal(false), d_type(type),
-    surrendered(false), abort_requested(false)
+    abort_requested(false)
 {
     if (player_no != -1)
 	d_id = player_no;
@@ -62,8 +61,7 @@ Player::Player(Glib::ustring name, guint32 armyset, Gdk::RGBA color,
 Player::Player(const Player& player)
     :d_color(player.d_color), d_name(player.d_name), d_armyset(player.d_armyset),
     d_dead(player.d_dead), d_immortal(player.d_immortal),
-    d_type(player.d_type), d_id(player.d_id), 
-    surrendered(player.surrendered),abort_requested(player.abort_requested)
+    d_type(player.d_type), d_id(player.d_id)
 {
     // as the other player is propably dumped somehow, we need to deep copy
     // everything.
@@ -90,7 +88,7 @@ Player::Player(const Player& player)
 }
 
 Player::Player(XML_Helper* helper)
-    :d_stacklist(0), surrendered(false), abort_requested(false)
+    :d_stacklist(0), abort_requested(false)
 {
     helper->getData(d_id, "id");
     helper->getData(d_name, "name");
@@ -125,8 +123,6 @@ Player* Player::create(Glib::ustring name, guint32 armyset, Gdk::RGBA color, Typ
   {
   case HUMAN:
     return (new RealPlayer(name, armyset, color));
-  case AI_DUMMY:
-    return (new AI_Dummy(name, armyset, color));
   }
 
   return 0;
@@ -138,14 +134,11 @@ Player* Player::create(Player* orig, Type type)
     {
         case HUMAN:
             return new RealPlayer(*orig);
-        case AI_DUMMY:
-            return new AI_Dummy(*orig);
     }
 
     return 0;
 }
 
-
 void Player::initTurn()
 {
   clearActionlist();
@@ -186,24 +179,6 @@ Glib::ustring Player::getName() const
   return d_name;
 }
 
-void Player::dumpActionlist() const
-{
-    for (list<Action*>::const_iterator it = d_actions.begin();
-        it != d_actions.end(); it++)
-    {
-        cerr <<(*it)->dump() << endl;
-    }    
-}
-
-void Player::dumpHistorylist() const
-{
-    for (list<History*>::const_iterator it = d_history.begin();
-        it != d_history.end(); it++)
-    {
-        cerr <<(*it)->dump() << endl;
-    }    
-}
-
 void Player::clearActionlist()
 {
     for (list<Action*>::iterator it = d_actions.begin();
@@ -302,8 +277,6 @@ Player* Player::loadPlayer(XML_Helper* helper)
     {
         case HUMAN:
             return new RealPlayer(helper);
-        case AI_DUMMY:
-            return new AI_Dummy(helper);
     }
 
     return 0;
@@ -516,48 +489,12 @@ Fight::Result Player::stackFight(Stack** attacker, Stack** defender,
     return fight.getResult();
 }
 
-void Player::doResign(std::list<History*> &histories)
-{
-
-  getStacklist()->setActivestack(0);
-  supdatingStack.emit(0);
-}
-
-void Player::resign() 
-{
-  std::list<History*> history;
-  doResign(history);
-  for (std::list<History*>::iterator i = history.begin(); i != history.end();
-       i++)
-    addHistory(*i);
-  
-  Action_Resign* item = new Action_Resign();
-  item->fillData();
-  addAction(item);
-}
-
-void Player::doRename(Glib::ustring name)
-{
-  setName(name);
-}
-
-void Player::rename(Glib::ustring name)
-{
-  doRename(name);
-  Action_RenamePlayer * item = new Action_RenamePlayer();
-  item->fillData(name);
-  addAction(item);
-  return;
-}
-
 Glib::ustring Player::playerTypeToString(const Player::Type type)
 {
   switch (type)
     {
     case Player::HUMAN:
       return "Player::HUMAN";
-    case Player::AI_DUMMY:
-      return "Player::AI_DUMMY";
     }
   return "Player::HUMAN";
 }
@@ -568,50 +505,9 @@ Player::Type Player::playerTypeFromString(const Glib::ustring str)
     return Player::Type(atoi(str.c_str()));
   if (str == "Player::HUMAN")
     return Player::HUMAN;
-  else if (str == "Player::AI_DUMMY")
-    return Player::AI_DUMMY;
   return Player::HUMAN;
 }
 
-bool Player::hasAlreadyInitializedTurn() const
-{
-  for (list<Action*>::const_iterator it = d_actions.begin();
-       it != d_actions.end(); it++)
-    if ((*it)->getType() == Action::INIT_TURN)
-      return true;
-  return false;
-}
-
-bool Player::hasAlreadyEndedTurn() const
-{
-  for (list<Action*>::const_iterator it = d_actions.begin();
-       it != d_actions.end(); it++)
-    if ((*it)->getType() == Action::END_TURN)
-      return true;
-  return false;
-}
-
-std::list<History*> Player::getHistoryForThisTurn() const
-{
-  std::list<History*> history;
-  for (list<History*>::const_reverse_iterator it = d_history.rbegin();
-       it != d_history.rend(); it++)
-    {
-      history.push_front(*it);
-      if ((*it)->getType() == History::START_TURN)
-	break;
-    }
-  return history;
-}
-
-void Player::setSurrendered(bool surr)
-{
-  surrendered = surr;
-}
-guint32 Player::countArmies() const
-{
-  return d_stacklist->countArmies();
-}
 Stack * Player::getActivestack() const
 {
   return d_stacklist->getActivestack();
@@ -621,11 +517,6 @@ void Player::setActivestack(Stack *s)
   d_stacklist->setActivestack(s);
 }
 	
-Vector<int> Player::getPositionOfArmyById(guint32 id) const
-{
-  return d_stacklist->getPosition(id);
-}
-
 void Player::clearStacklist()
 {
   d_stacklist->flClear();
@@ -704,7 +595,6 @@ guint32 Player::count_reinforcements_this_turn() const
   return count;
 }
 
-
 std::list<Stack*> Player::doReinforce(std::list<Army*> armies)
 {
   Vector<int> dest = GameMap::getReinforcementPoint();
