@@ -18,7 +18,6 @@
 #ifndef PLAYER_H
 #define PLAYER_H
 
-#include <string>
 #include <list>
 #include <vector>
 #include <sigc++/trackable.h>
@@ -49,7 +48,6 @@ class Player: public sigc::trackable
         //! The available player types.
         enum Type {
 	  HUMAN = 0, 
-	  AI_DUMMY = 1, 
 	};
 
         /** 
@@ -80,9 +78,6 @@ class Player: public sigc::trackable
 
 	// Set Methods
 
-        //! Change the player's name.
-        void setName(Glib::ustring name){d_name = name;}
-        
         //! Change the player's Armyset.
         void setArmyset(guint32 armyset){d_armyset = armyset;}
 
@@ -98,16 +93,6 @@ class Player: public sigc::trackable
         //! Revive the player, this does not provide any cities.
         void revive() {d_dead = false;}
 
-	//! Set whether or not this player has surrendered.
-	/*
-	 * computer players may surrender to a lone human player who has most
-	 * of the cities on the board.
-	 * this method merely sets the surrendered member so that we can
-	 * quit properly. e.g. it triggers the aborted_Turn signal to be fired
-	 * at a different time in fast, smart and dummy players.
-	 */
-	void setSurrendered(bool surr);
-
 	// Get Methods
 
 	//! Returns whether or not this is a computer player.
@@ -147,23 +132,11 @@ class Player: public sigc::trackable
         //! Remove every Action from the list of the player's actions.
         void clearActionlist();
 
-        //! Show debugging information for the player's Action list.
-        void dumpActionlist() const;
-
-	//! Check to see if it's our turn.
-	bool hasAlreadyInitializedTurn() const;
-
-	//! Check to see if we've ended our turn this round.
-	bool hasAlreadyEndedTurn() const;
-
 	// Methods that operate on the player's history list.
 
         //! Remove every History element from the list of the player's events.
         void clearHistorylist();
 
-        //! Show debugging information for the player's History list.
-        void dumpHistorylist() const;
-
 	//! Add a new history item to the player's history list.
 	void addHistory(History *history);
 
@@ -177,18 +150,12 @@ class Player: public sigc::trackable
 
 	// Methods that operate on the player's stacklist
 
-	//! Return the grand total of the player's armies.
-	guint32 countArmies() const;
-
 	//! Return the player's currently selected stack.
 	Stack * getActivestack() const;
 
 	//! Select this stack.
 	void setActivestack(Stack *);
 
-	//! Return the position on the map for the given army unit.
-	Vector<int> getPositionOfArmyById(guint32 id) const;
-
 	//! Remove all stacks from the player's list.
 	void clearStacklist();
 
@@ -277,9 +244,6 @@ class Player: public sigc::trackable
         //! record the player's end of turn.
         void reportEndOfTurn();
 
-	//! Give the player a new name.
-	void rename (Glib::ustring name);
-
         //! Mark the player as dead. Kills all Army units in the Stacklist.
         void kill();
 
@@ -289,24 +253,6 @@ class Player: public sigc::trackable
         //! Deselect any and all stacks.
         void stackDeselect();
 
-	/**
-	 * Callback to have the Player resign.  This entails disbanding
-	 * all of the player's stacks and then razing all of the player's 
-	 * remaining cities.  It also removes all of the gold pieces from 
-	 * the player's treasury.
-	 *
-	 * This callback is called when a human player wants to surrender
-	 * ungracefully.  Computer players do not currently consider
-	 * calling this method to surrender, and they use a different
-	 * mechanism to collectively surrender to a final human player.
-	 *
-	 * This callback must result in a Action_Resign element being
-	 * given to the addAction method.
-	 *
-	 */
-        //! Callback to disband all the player's stacks and raze all cities.
-        void resign();
-
         guint32 countEndTurnHistoryEntries() const;
         void getArmyTypesKilled(std::list<guint32> &armies, Player* owner) const;
         std::list<guint32> getArmyTypesReinforced() const;
@@ -437,20 +383,12 @@ class Player: public sigc::trackable
 	//! A list of the Player's Stack objects.
         Stacklist* d_stacklist;
 
-	//! Whether or not this player has surrendered.
-	bool surrendered;
-
         //! Whether or not someone has closed the main game window.
         bool abort_requested;
 
-        void doResign(std::list<History*> &history);
-        void doRename(Glib::ustring name);
 	void doKill();
         void doStackSelect(Stack *stack);
         void doStackDeselect();
-	void pruneActionlist();
-	static void pruneActionlist(std::list<Action*> actions);
-	std::list<History*> getHistoryForThisTurn() const;
         std::list<Stack*> doReinforce(std::list<Army*> armies);
 	    
     private:
