@@ -23,12 +23,10 @@
 #include "playerlist.h"
 #include "armysetlist.h"
 
-#include "stacklist.h"
 #include "xmlhelper.h"
 #include "history.h"
 #include "stacklist.h"
 #include "real_player.h"
-#include "ai_dummy.h"
 #include "GameMap.h"
 
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
@@ -166,16 +164,6 @@ void Playerlist::nextPlayer()
     debug("got player: " <<d_activeplayer->getName())
 }
 
-Player* Playerlist::getPlayer(Glib::ustring name) const
-{
-    debug("getPlayer()");
-    for (const_iterator it = begin(); it != end(); ++it)
-    {
-        if ((*it)->getName() == name) return (*it);
-    }
-    return 0;
-}
-
 Player* Playerlist::getPlayer(guint32 id) const
 {
   IdMap::const_iterator it = d_id.find(id);
@@ -228,6 +216,7 @@ void Playerlist::add(Player *player)
   push_back(player);
   d_id[player->getId()] = player;
 }
+
 bool Playerlist::load(Glib::ustring tag, XML_Helper* helper)
 {
     static guint32 active = 0;
@@ -260,15 +249,6 @@ Playerlist::iterator Playerlist::flErase(Playerlist::iterator it)
     return erase (it);
 }
 
-guint32 Playerlist::countHumanPlayersAlive() const
-{
-  guint32 retval = 0;
-  for (const_iterator it = begin(); it != end(); it++)
-    if ((*it)->isDead() == false && (*it)->getType() == Player::HUMAN)
-      retval++;
-  return retval;
-}
-
 guint32 Playerlist::countPlayersAlive () const
 {
   guint32 numAlive = 0; 
@@ -282,18 +262,6 @@ guint32 Playerlist::countPlayersAlive () const
   return numAlive;
 }
 
-void Playerlist::surrender()
-{
-  //the last human player has accepted surrender
-  for (iterator it = begin(); it != end(); it++)
-    {
-      if ((*it)->getType() != Player::HUMAN)
-	{
-	  (*it)->setSurrendered(true);
-	}
-    }
-}
-
 bool Playerlist::isEndOfRound() const
 {
   //check to see if all players have moved this round.
@@ -311,17 +279,6 @@ bool Playerlist::isEndOfRound() const
   return true;
 }
 
-bool Playerlist::hasArmyset(guint32 id) const
-{
-  for (const_iterator it = begin(); it != end(); it++)
-    {
-      Player *p = (*it);
-      if (p->getArmyset() == id)
-        return true;
-    }
-  return false;
-}
-
 void Playerlist::clearAllActions()
 {
   for (iterator it = begin(); it != end(); it++)
