@@ -112,21 +112,12 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 
 	// Methods that operate on class and do not modify the class
 
-        //! Does the stack contain this kind of army?
-        bool hasArmyType(guint32 army_type) const;
-
         //! Save the stack to an opened saved-game file.
         bool save(XML_Helper* helper) const;
 
 	//! Go find the army with this identifier in the stack and return it.
         Army* getArmyById(guint32 id) const;
         
-	//! Does everything in this stack look okay?
-	bool validate() const;
-
-	//! Does this stack have 8 units in it?
-	bool isFull() const;
-
         bool hasGeneral() const;
 
         double getMaximumMoves() const;
@@ -152,13 +143,6 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	//! Emitted when this stack has finished moving that one step
 	sigc::signal<void, Stack*> smoved;
 
-
-	// Static Methods
-        
-
-	//! Create a stack with an id that isn't unique.
-	static Stack* createNonUniqueStack(Player *player, Vector<int> pos);
-
     private:    
 
 	//! Private constructor.
