@@ -34,21 +34,6 @@ Glib::ustring Stacklist::d_tag = "stacklist";
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
-Vector<int> Stacklist::getPosition(guint32 id)
-{
-    for (Playerlist::iterator pit = Playerlist::getInstance()->begin();
-        pit != Playerlist::getInstance()->end(); pit++)
-    {
-        Stacklist* mylist = (*pit)->getStacklist();
-        for (const_iterator it = mylist->begin(); it !=mylist->end(); it++)
-            for (Stack::const_iterator sit = (*it)->begin(); sit != (*it)->end(); sit++)
-                if ((*sit)->getId() == id)
-                    return (*it)->getPos();
-    }
-
-    return Vector<int>(-1,-1);
-}
-
 //search all player's stacklists to find this stack
 bool Stacklist::deleteStack(Stack* s)
 {
@@ -189,14 +174,6 @@ Stacklist::iterator Stacklist::flErase(iterator object)
     return erase(object);
 }
 
-bool Stacklist::flRemove(guint32 id)
-{
-  Stack *s = getStackById(id);
-  if (s == NULL)
-    return false;
-  return flRemove(s);
-}
-
 bool Stacklist::flRemove(Stack* object)
 {
   if (object == NULL)
@@ -306,6 +283,7 @@ void Stacklist::on_stack_died (Stack *stack)
   d_id.erase(d_id.find(stack->getId()));
   return;
 }
+
 void Stacklist::on_stack_starts_moving (Stack *stack)
 {
   deletePositionFromMap(stack);
@@ -321,18 +299,6 @@ void Stacklist::setActivestack(Stack* activestack)
   d_activestack = activestack;
 }
 
-std::list<Vector<int> > Stacklist::getPositions() const
-{
-  std::list<Vector<int> > points;
-  for (const_iterator it = begin(); it != end(); it++)
-    {
-      if (std::find(points.begin(), points.end(), (*it)->getPos()) == 
-          points.end())
-        points.push_back((*it)->getPos());
-    }
-  return points;
-}
-
 bool Stacklist::hasGeneral() const
 {
   for (const_iterator it = begin(); it != end(); it++)
