@@ -16,11 +16,6 @@
 //  02110-1301, USA.
 
 #include "tarhelper.h"
-#include <fcntl.h>
-#include <string.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <fstream>
 #include "File.h"
 #include <errno.h>
 #include "ucompose.hpp"
@@ -170,7 +165,7 @@ void Tar_Helper::Close()
         }
       t = NULL;
       if (tmpoutdir != "")
-        File::erase_dir(tmpoutdir);
+        File::clean_dir(tmpoutdir);
     }
 }
 
@@ -322,11 +317,6 @@ bool Tar_Helper::is_tarfile (Glib::ustring file)
   return retval;
 }
 
-bool Tar_Helper::removeFile(Glib::ustring filename)
-{
-  return replaceFile(filename, "");
-}
-
 int Tar_Helper::dump_file_entry (struct archive *in, Glib::ustring filename, struct archive_entry *entry, Glib::ustring nameinarchive, struct archive *out)
 {
     struct stat st;
@@ -334,65 +324,22 @@ int Tar_Helper::dump_file_entry (struct archive *in, Glib::ustring filename, str
     archive_entry_copy_stat(entry, &st);
     archive_entry_set_pathname(entry, nameinarchive.c_str());
     archive_write_header(out, entry);
-    int fd = open (filename.c_str(), O_RDONLY);
-    if (fd < 0)
+    std::ifstream infile(filename.c_str(), std::ios::in);
+    if (!infile)
       return ARCHIVE_FATAL;
     char buff[8192];
 
-    ssize_t len = read (fd, buff, sizeof (buff));
-    while (len > 0)
+    infile.read (buff, sizeof (buff));
+    while (infile.gcount() > 0)
       {
-        archive_write_data (out, buff, len);
-        len = read (fd, buff, sizeof (buff));
+        archive_write_data (out, buff, infile.gcount());
+        infile.read (buff, sizeof (buff));
       }
     archive_write_finish_entry(out);
-    close(fd);
+    infile.close();
     return ARCHIVE_OK;
 }
 
-bool Tar_Helper::replaceFile(Glib::ustring filename, Glib::ustring newfilename)
-{
-  if (newfilename != "" && File::exists(newfilename) == false)
-    return false;
-  //loop through existing file entries and copy them out.
-  //when we see the one we want to replace, we do so.
-  //unless newfilename is "", in which case we skip it (remove it).
-  //write the whole tar file to a temporary file and then copy it in place.
-  Glib::ustring tmp = File::get_tmp_file();
-  bool broken = false;
-  Tar_Helper out(tmp, std::ios::out, broken);
-  Tar_Helper in(pathname, std::ios::in, broken);
-  if (!broken)
-    {
-      struct archive_entry *in_entry = NULL;
-      while (1) 
-        {
-          int r = archive_read_next_header(in.t, &in_entry);
-          if (r == ARCHIVE_EOF)
-            break;
-          if (r != ARCHIVE_OK)
-            break;
-          if (filename == archive_entry_pathname(in_entry) &&
-              newfilename != "")
-            {
-              //hey it's the one we want to replace
-              dump_file_entry (in.t, newfilename, in_entry, 
-                               File::get_basename(newfilename, true), out.t);
-            }
-          else
-            dump_entry(in.t, in_entry, out.t);
-        }
-      in.Close();
-    }
-
-  out.Close();
-  archive_write_free(t);
-  t = NULL;
-  File::copy(tmp, pathname);
-  File::erase(tmp);
-  return true;
-}
-
 void Tar_Helper::clean_tmp_dir(Glib::ustring filename)
 {
   Glib::ustring tmpoutdir = 
