@@ -637,29 +637,6 @@ bool XML_Helper::tag_open(Glib::ustring tag, Glib::ustring version, Glib::ustrin
     return true;
 }
 
-bool XML_Helper::lang_check(Glib::ustring lang)
-{
-  static char *envlang = getenv("LANG");
-  if (envlang == NULL)
-    envlang = getenv("LC_ALL");
-  if (envlang == NULL)
-    envlang = getenv("LC_CTYPE");
-  if (lang == "")
-    return true;
-  if (envlang == NULL)
-    return false;
-  if (lang == envlang)
-    return true;
-  //try harder
-  char *first_underscore = strchr (envlang, '_');
-  if (first_underscore)
-    {
-      if (strncmp (lang.c_str(), envlang, first_underscore - envlang) == 0)
-	return true;
-    }
-  return false;
-}
-
 bool XML_Helper::tag_close(Glib::ustring tag, Glib::ustring cdata)
 {
     if (d_failed)
@@ -671,8 +648,7 @@ bool XML_Helper::tag_close(Glib::ustring tag, Glib::ustring cdata)
     if ((tag[0] == 'd') && (tag[1] == '_'))
     {
         // save the data (we close a data tag)
-	if (lang_check(d_lang[tag]))
-	  d_data[tag] = cdata;
+        d_data[tag] = cdata;
         return true;    //data tags end here with their execution
     }
 
@@ -703,76 +679,6 @@ bool XML_Helper::tag_close(Glib::ustring tag, Glib::ustring cdata)
     return true;
 }
 
-Glib::ustring XML_Helper::get_top_tag(Glib::ustring filename)
-{
-  char buffer[1024];
-  XML_Helper in(filename, std::ios::in);
-  while (in.d_in->eof() == false)
-    {
-      in.d_in->getline(buffer, sizeof buffer);
-      Glib::ustring line(buffer);
-      if (line.find("<?xml version=\"1.0\"") == 0)
-        continue;
-      size_t start = line.find('<');
-      if (start == Glib::ustring::npos)
-        continue;
-      size_t finish = line.find(" version=", start + 1);
-      if (finish == Glib::ustring::npos)
-        continue;
-      in.close();
-      return line.substr(start + 1, finish - start - 1);
-    }
-  in.close();
-  return "";
-}
-
-bool XML_Helper::rewrite_version(Glib::ustring filename, Glib::ustring tag, Glib::ustring new_version)
-{
-  Glib::ustring match = "<" + tag + " version=\"";
-  bool found = false;
-  char buffer[1024];
-  Glib::ustring tmpfile = File::get_tmp_file();
-  XML_Helper in(filename, std::ios::in);
-  XML_Helper out(tmpfile, std::ios::out);
-  while (in.d_in->eof() == false)
-    {
-      in.d_in->getline(buffer, sizeof buffer);
-      Glib::ustring line(buffer);
-      if (line.compare(0, match.length(), match) == 0 && found == false)
-        {
-          found = true;
-          Glib::ustring upgraded_line = match + new_version + "\">";
-          out.d_out->write(upgraded_line.c_str(), upgraded_line.length());
-          (*out.d_out) << std::endl;
-        }
-      else
-        {
-          int len = in.d_in->gcount();
-          size_t pos = line.rfind("\r\n");
-          if (pos == Glib::ustring::npos)
-            {
-              pos = line.rfind('\n');
-              if (pos != Glib::ustring::npos)
-                len--;
-            }
-          else
-            len-=2;
-          if (len)
-            {
-              if (buffer[len-1] == '\0')
-                len--;
-              out.d_out->write(buffer, len);
-            }
-          (*out.d_out) << std::endl;
-        }
-    }
-  out.close();
-  in.close();
-  File::erase(filename);
-  rename(tmpfile.c_str(), filename.c_str());
-  return found;
-}
-
 void XML_Helper::on_start_element(const Glib::ustring& name, const AttributeList& a)
 {
   Glib::ustring version, lang;
