@@ -74,7 +74,6 @@
 #define XML_HELPER_H
 
 #include <gtkmm.h>
-#include <string>
 #include <iostream>
 #include <fstream>
 #include <list>
@@ -201,10 +200,6 @@ class XML_Helper: public xmlpp::SaxParser
         //! Use this function to start reading a file or stream
         bool parseXML();
 
-        static Glib::ustring get_top_tag(Glib::ustring filename);
-        static bool rewrite_version(Glib::ustring filename, Glib::ustring tag, Glib::ustring new_version);
-        
-
     protected:
         virtual void on_start_element(const Glib::ustring& name,
                                                                       const AttributeList& properties);
@@ -218,8 +213,6 @@ class XML_Helper: public xmlpp::SaxParser
           */
         inline void addTabs();
 
-	bool lang_check(Glib::ustring lang);
-
         bool tag_open(Glib::ustring tag, Glib::ustring version, Glib::ustring lang);
 
         bool tag_close(Glib::ustring tag, Glib::ustring cdata = "");
